% Script to reproduce Fig. 5 (top pannel) of:
% de Cheveign, A., Arzounian, D., Robust detrending, rereferencing,
% outlier detection, and inpainting for multichannel data,(submitted to
% NeuroImage).
%
% Note: this script requires the NoiseTools toolbox
% (http://audition.ens.fr/adc/NoiseTools/). It should work with version
% 05-Jul-2017.

clear;

%% Load EEG data from file for top pannel
if 0 % Initial creation of MAT data file from raw source file   
    % Ensure that biosig works:
    if 2 ~=exist('sopen')
        error('download BioSig from http://biosig.sourceforge.net');
    end
    x = fileparts( which('sopen') );
    rmpath(x);
    addpath(x,'-begin');
    % Get data from raw source file:
    fname='/DATA/MEG/LeGal/ADC_MLGDK_150619_pd01/ADC_MLGDK_150619_pd01_02.bdf';
    h=sopen(fname);
    x=sread(h);
    % Down-sample signal
    DSR=20; % Down-sampling ratio
    sr=h.SampleRate/DSR; % New sampling rate
    x=nt_dsample(x,DSR); % Down-sampled signal
    % Subtract the mean of each channel
    x=nt_demean(x);
    % Save relevant data
    save fig_5_data x sr fname
else 
    load fig_5_data
end

%% Prepare signal and perform robust detrending:
% Keep a smaller time interval to zoom a bit:
x=nt_demean(x(1:21000,:));
% Convert from V to mV:
x=x/1000;
% Perform robust detrending on channel of interest:
ch=1; % Channel number
[y,w]=nt_detrend(x(:,ch),50,[],[],3.5); % Detrended signal
z=x(:,ch)-y; % Removed polynomial trend
t=(0:size(x,1)-1)'/sr; % Time vector

%% Plot raw and detrended signals:
% Prepare figure
figure(1); clf; set(gcf,'color', [1 1 1], 'position',[100 100 600 200])
 
% Plot raw signal and trend on the left:
subplot 121;
plot(t,z,'r','linewidth', 2); % trend
hold on; plot(t,[x(:,ch)], 'k'); % raw signal
% Set axes properties:
mx=max(x(:,ch)); mn=min(x(:,ch));
ylim([-.5 .5]); xlim([t(1)-3 t(end)+3]);
set(gca,'fontsize',14,'ytick',[-.5 0 .5]); xlabel('time (s)'); ylabel('amplitude (mV)');
title('raw')

% Plot detrended signal on the right:
subplot 122;
plot(t,nt_demean(y), 'k')
% Set axes proporties:
ylim([-.5 .5]); xlim([t(1)-3 t(end)+3]);
set(gca,'fontsize',14,'ytick',[]); xlabel('time (s)')
title('robust detrend')

% Save two panels:
set(gcf, 'PaperPositionMode', 'auto');
print ('-depsc2', 'Fig_5_top')

